@@ -147,7 +147,7 @@ def sqlalchemy_result_format(results, format_datetime=False):
     return output
 
 
-def sqlalchemy_data_commit(models: Base,
+def sqlalchemy_data_commit(models,
                            data_lst: list, mode='ignore',
                            on_duplicate_key='',
                            auto_commit=False,
